@@ -213,9 +213,9 @@ class MainWindow(gobject.GObject):
 	def Show(self, dock_widget = None):
 		"""shows the main window. if given a widget, it will put itself in the widget.  otherwise load a regular
 		application window"""
-		if not utils.HAS_MOZILLA and self.layout.endswith("planet"):
-			logging.warning("requested planet layout, but can't use because gtkmozembed isn't installed correctly (won't import)")
-			self.layout = "standard"
+		#if not utils.HAS_MOZILLA and self.layout.endswith("planet"):
+		#	logging.warning("requested planet layout, but can't use because gtkmozembed isn't installed correctly (won't import)")
+		#	self.layout = "standard"
 		if utils.RUNNING_SUGAR:  #if we are in OLPC mode and just have to supply a widget...
 			self._status_view = None
 			self._disk_usage_widget = None
@@ -309,8 +309,8 @@ class MainWindow(gobject.GObject):
 				self._widgetTree.get_widget('separator11').hide()
 				self._widgetTree.get_widget('reindex_searches').hide()
 				self._widgetTree.get_widget('add_feed_filter').hide()
-			if not utils.HAS_MOZILLA:
-				self._widgetTree.get_widget('planet_layout').hide()
+			#if not utils.HAS_MOZILLA:
+				#self._widgetTree.get_widget('planet_layout').hide()
 			if not utils.HAS_STATUS_ICON:
 				self._widgetTree.get_widget('show_notifications').hide()
 			self.window = self.app_window
@@ -399,7 +399,7 @@ class MainWindow(gobject.GObject):
 		self._sugar_remove_button = ToolButton('gtk-remove')
 		vbox = gtk.VBox()
 		#vbox.set_size_request(300, 200)
-		label = gtk.Label(_('Really delete feed?'))
+		label = gtk.Label(_('Really remove feed?'))
 		vbox.pack_start(label)
 		hbox = gtk.HBox()
 		expander_label = gtk.Label(' ')
@@ -553,20 +553,24 @@ class MainWindow(gobject.GObject):
 			if key[:3] == 'on_':
 				self._widgetTree.signal_connect(key, getattr(self, key))
 				
-	def show_window_add_feed(self):
+	def show_window_add_feed(self, autolocation=True):
 		import AddFeedDialog
 		if self._window_add_feed is None:
 			if utils.RUNNING_HILDON:
 				self._window_add_feed = AddFeedDialog.AddFeedDialog(gtk.glade.XML(os.path.join(self._glade_prefix,'hildon_dialog_add_feed.glade'), "window_add_feed",'penguintv'),self._app) #MAGIC
 			else:
 				self._window_add_feed = AddFeedDialog.AddFeedDialog(gtk.glade.XML(os.path.join(self._glade_prefix,'dialog_add_feed.glade'), "window_add_feed",'penguintv'),self._app) #MAGIC
-		self._window_add_feed.show()
+		self._window_add_feed.show(autolocation)
 			
 	def hide_window_add_feed(self):
 		if self._window_add_feed is None:
 			self.show_window_add_feed()
 			
 		self._window_add_feed.hide()
+		
+	def set_window_add_feed_location(self, url):
+		assert self._window_add_feed is not None
+		self._window_add_feed.set_location(url)
 				
 	def load_notebook(self):
 		self._notebook = NotebookManager()
@@ -633,12 +637,17 @@ class MainWindow(gobject.GObject):
 			fancy = True
 		
 		self.feed_list_view = FeedList.FeedList(components,self._app, fancy)
-		assert utils.HAS_MOZILLA
-		renderer = EntryFormatter.MOZILLA
-		
-		if self.layout.endswith("planet") and renderer != EntryFormatter.MOZILLA:
-			self.layout = "standard"
-			return self.load_layout()	
+		#renderer = EntryFormatter.MOZILLA
+		#renderer = EntryFormatter.GTKHTML
+		if utils.RUNNING_HILDON:
+			renderer = EntryFormatter.GTKHTML
+		else:
+			assert utils.HAS_MOZILLA
+			renderer = EntryFormatter.MOZILLA
+		#
+		#if self.layout.endswith("planet") and renderer != EntryFormatter.MOZILLA:
+		#	self.layout = "standard"
+		#	return self.load_layout()	
 		
 		if not self.layout.endswith("planet"):
 			self.entry_list_view = EntryList.EntryList(components, self._app, 
@@ -1401,8 +1410,8 @@ class MainWindow(gobject.GObject):
 		if selected:
 			self._notebook.set_current_page(N_FEEDS)
 			if not override:
-				dialog = gtk.Dialog(title=_("Really Delete Feed?"), parent=None, flags=gtk.DIALOG_MODAL, buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_DELETE, gtk.RESPONSE_ACCEPT))
-				label = gtk.Label(_("Are you sure you want to delete this feed, all its entries, and all its media?  \nThis operation cannot be undone."))
+				dialog = gtk.Dialog(title=_("Really Remove Feed?"), parent=None, flags=gtk.DIALOG_MODAL, buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_REMOVE, gtk.RESPONSE_ACCEPT))
+				label = gtk.Label(_("Are you sure you want to remove this feed, all its entries, and all its media?  \nThis operation cannot be undone."))
 				dialog.vbox.pack_start(label, True, True, 0)
 				label.show()
 				dialog.set_transient_for(self._app.main_window.get_parent())
@@ -1642,7 +1651,7 @@ class MainWindow(gobject.GObject):
 				for tag,favorite in tags:
 					i+=1
 					self._filters.append([favorite, tag,tag,ptvDB.T_SEARCH])
-					completion_model.append([tag,_('tag: %s') % (tag,), i])
+					completion_model.append([tag,_('tag: %s') % (tag,), i - 1])
 					if favorite > 0:
 						self._favorite_filters.append([favorite, tag,tag, i])
 		
@@ -1652,7 +1661,7 @@ class MainWindow(gobject.GObject):
 			for tag,favorite in tags:
 				i+=1
 				self._filters.append([favorite, tag,tag+" ("+str(self._app.db.get_count_for_tag(tag))+")",ptvDB.T_TAG])
-				completion_model.append([tag,_('tag: %s') % (tag,), i])
+				completion_model.append([tag,_('tag: %s') % (tag,), i - 1])
 				if favorite > 0:
 					self._favorite_filters.append([favorite, tag,tag+" ("+str(self._app.db.get_count_for_tag(tag))+")", i])
 				
