@@ -7,6 +7,9 @@
 
 import logging
 import os, os.path
+import threading
+import re
+import time
 
 import gobject
 import gtk
@@ -14,8 +17,13 @@ import gtk
 import EntryFormatter
 import ptvDB
 import utils
+import ThreadPool
 
-if not utils.RUNNING_SUGAR:
+if utils.RUNNING_HILDON:
+	pass
+elif utils.RUNNING_SUGAR:
+	import hulahop
+else:
 	try:
 		import gtkmozembed
 	except:
@@ -23,9 +31,6 @@ if not utils.RUNNING_SUGAR:
 			from ptvmozembed import gtkmozembed
 		except:
 			pass
-else:
-	import hulahop
-	
 
 if utils.RUNNING_HILDON:
 	ENTRIES_PER_PAGE = 5
@@ -36,6 +41,8 @@ else:
 S_DEFAULT=0
 S_SEARCH=1
 
+IMG_REGEX = re.compile("<img.*?src=[\",\'](.*?)[\",\'].*?>", re.IGNORECASE|re.DOTALL)
+
 class PlanetView(gobject.GObject):
 	"""PlanetView implementes the api for entrylist and entryview, so that the main program doesn't
 	need to know that the two objects are actually the same"""
@@ -77,7 +84,6 @@ class PlanetView(gobject.GObject):
 		self._renderer = renderer
 		self._css = ""
 		self._current_feed_id = -1
-		self._moz_realized = False
 		self._feed_title=""
 		self._state = S_DEFAULT
 		self._auth_info = (-1, "","") #user:pass, url
@@ -118,6 +124,7 @@ class PlanetView(gobject.GObject):
                 style.base[gtk.STATE_INSENSITIVE].green / 256)
 		
 		if self._renderer == EntryFormatter.MOZILLA:
+			self._moz_realized = False
 			if utils.RUNNING_SUGAR:
 				f = open(os.path.join(share_path, "mozilla-planet-olpc.css"))
 				for l in f.readlines(): self._css += l
@@ -129,6 +136,17 @@ class PlanetView(gobject.GObject):
 					f = open(os.path.join(share_path, "mozilla-planet.css"))
 				for l in f.readlines(): self._css += l
 				f.close()
+		elif self._renderer == EntryFormatter.GTKHTML:
+			f = open(os.path.join(share_path, "gtkhtml.css"))
+			#f = open(os.path.join(share_path, "mozilla-planet-hildon.css"))
+			for l in f.readlines(): self._css += l
+			f.close()
+			self._current_scroll_v = self._scrolled_window.get_vadjustment().get_value()
+			self._current_scroll_h = self._scrolled_window.get_hadjustment().get_value()
+			self._image_pool = ThreadPool.ThreadPool(5, "PlanetView")
+			#self._image_lock = threading.Lock()
+			self._dl_total = 0
+			self._dl_count = 0
 				
 		#signals
 		self._handlers = []
@@ -202,6 +220,28 @@ class PlanetView(gobject.GObject):
 				self._conf = gconf.client_get_default()
 				self._conf.notify_add('/desktop/gnome/interface/font_name',self._gconf_reset_moz_font)
 			self._reset_moz_font()
+		elif self._renderer == EntryFormatter.GTKHTML:
+			import gtkhtml2
+			import SimpleImageCache
+			import threading
+			self._scrolled_window.set_property("shadow-type",gtk.SHADOW_IN)
+			htmlview = gtkhtml2.View()
+			self._document = gtkhtml2.Document()
+			self._document.connect("link-clicked", self._gtkhtml_link_clicked)
+			htmlview.connect("on_url", self._gtkhtml_on_url)
+			self._document.connect("request-url", self._gtkhtml_request_url)
+			htmlview.get_vadjustment().set_value(0)
+			htmlview.get_hadjustment().set_value(0)
+			self._scrolled_window.set_hadjustment(htmlview.get_hadjustment())
+			self._scrolled_window.set_vadjustment(htmlview.get_vadjustment())
+			
+			self._document.clear()
+			htmlview.set_document(self._document)		
+			self._scrolled_window.add(htmlview)
+			self._htmlview = htmlview
+			self._document_lock = threading.Lock()
+			self._image_cache = SimpleImageCache.SimpleImageCache()
+			
 		self.display_item()
 		self._html_dock.show_all()
 		if self._USING_AJAX:
@@ -209,7 +249,7 @@ class PlanetView(gobject.GObject):
 			import threading
 			from ajax import EntryInfoServer, MyTCPServer
 			
-			store_location = os.path.join(self._db.get_setting(ptvDB.STRING, '/apps/penguintv/media_storage_location', ""), "images")
+			store_location = os.path.join(self._db.get_setting(ptvDB.STRING, '/apps/penguintv/media_storage_location', ""), os.path.join(utils.get_home(), "media", "images"))
 
 			while True:
 				try:
@@ -225,13 +265,13 @@ class PlanetView(gobject.GObject):
 			t.setDaemon(True)
 			t.start()
 			self._ajax_url = "http://localhost:"+str(PlanetView.PORT)+"/"+self._update_server.get_key()
-			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, ajax_url=self._ajax_url)
-			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, ajax_url=self._ajax_url)
+			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, ajax_url=self._ajax_url, renderer=self._renderer)
+			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, ajax_url=self._ajax_url, renderer=self._renderer)
 		else:
 			logging.info("not using ajax")
 			self._ajax_url = None
-			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, basic_progress=True)
-			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, basic_progress=True)
+			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, basic_progress=True, renderer=self._renderer)
+			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, basic_progress=True, renderer=self._renderer)
 		
 	def set_entry_view(self, entry_view):
 		pass
@@ -340,6 +380,8 @@ class PlanetView(gobject.GObject):
 			#self._main_window.set_hide_entries_visibility(True)
 			self._current_feed_id = feed_id
 			self._first_entry = 0
+			if self._renderer == EntryFormatter.GTKHTML:
+				self._gtkhtml_reset_image_dl()
 			self._entry_store={}
 			feed_info = self._db.get_feed_info(feed_id)
 			if feed_info['auth_feed']:
@@ -408,6 +450,8 @@ class PlanetView(gobject.GObject):
 		self._entry_store={}
 		self._entrylist = []
 		self._convert_newlines = False
+		if self._renderer == EntryFormatter.GTKHTML:
+			self._gtkhtml_reset_image_dl()
 		self._render("<html><body></body></html")
 		if self._USING_AJAX:
 			self._update_server.clear_updates()
@@ -472,8 +516,11 @@ class PlanetView(gobject.GObject):
 			except:
 				logging.error('error closing planetview server')
 		self._render("<html><body></body></html")
-		if not utils.RUNNING_SUGAR and not utils.RUNNING_HILDON:
+		if not utils.RUNNING_SUGAR and not utils.RUNNING_HILDON and self._renderer == EntryFormatter.MOZILLA:
 			gtkmozembed.pop_startup()
+		if self._renderer == EntryFormatter.GTKHTML:
+			self._image_pool.joinAll(False, False)
+			del self._image_pool
 					
 	#protected functions
 	def _render_entries(self, mark_read=False, force=False):
@@ -481,6 +528,8 @@ class PlanetView(gobject.GObject):
 
 		if self._first_entry < 0:
 			self._first_entry = 0
+			if self._renderer == EntryFormatter.GTKHTML:
+				self._gtkhtml_reset_image_dl()
 			
 		if self._filter_feed is not None:
 			assert self._state == S_SEARCH
@@ -565,21 +614,21 @@ class PlanetView(gobject.GObject):
 					<tr><td>""")
 		if self._first_entry > 0:
 			if utils.RUNNING_HILDON:
-				html.append(_('<a href="planet:up" style="text-size: 20pt">Newer Entries</a>'))
+				html.append(_('<a href="planet:up" style="font-size: 20pt">Newer Entries</a>'))
 			else:
 				html.append(_('<a href="planet:up">Newer Entries</a>'))
 		
 		html.append('</td><td style="text-align: right;">')
 		if self._last_entry < len(entrylist):
 			if utils.RUNNING_HILDON:
-				html.append(_('<a href="planet:down" style="text-size: 20pt">Older Entries</a>'))
+				html.append(_('<a href="planet:down" style="font-size: 20pt">Older Entries</a>'))
 			else:
 				html.append(_('<a href="planet:down">Older Entries</a>'))
 			
 		html.append("</td></tr></tbody></table></div>")
 		
 		if self._state != S_SEARCH:
-			html.append('<div class="feed_title">'+self._feed_title+"</div>")
+			html.append('<div class="feedtitle">'+self._feed_title+"</div>")
 		html += entries
 			
 		html.append("""<div id="nav_bar"><table
@@ -589,13 +638,13 @@ class PlanetView(gobject.GObject):
 					<tr><td>""")
 		if self._first_entry > 0:
 			if utils.RUNNING_HILDON:
-				html.append(_('<a href="planet:up" style="text-size: 20pt">Newer Entries</a>'))
+				html.append(_('<a href="planet:up" style="font-size: 20pt">Newer Entries</a>'))
 			else:
 				html.append(_('<a href="planet:up">Newer Entries</a>'))
 		html.append('</td><td style="text-align: right;">')
 		if self._last_entry < len(entrylist):
 			if utils.RUNNING_HILDON:
-				html.append(_('<a href="planet:down" style="text-size: 20pt">Older Entries</a>'))
+				html.append(_('<a href="planet:down" style="font-size: 20pt">Older Entries</a>'))
 			else:
 				html.append(_('<a href="planet:down">Older Entries</a>'))
 		html.append("</td></tr></tbody></table></div>")
@@ -613,18 +662,18 @@ class PlanetView(gobject.GObject):
 	def _build_header(self, media_exists):
 		if self._renderer == EntryFormatter.MOZILLA:
 			html = ["""<html><head>
-				    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-					<style type="text/css">
-				    body { background-color: %s; color: %s; font-family: %s; font-size: %s; }
-				    %s
-				    </style>
-				    <title>title</title>""" % (self._background_color,
-											   self._foreground_color,
-											   self._moz_font, 
-											   self._moz_size, 
-											   self._css)] 
-			html.append("""<script type="text/javascript"><!--""")
+			    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
+				<style type="text/css">
+			    body { background-color: %s; color: %s; font-family: %s; font-size: %s; }
+			    %s
+			    </style>
+			    <title>title</title>""" % (self._background_color,
+										   self._foreground_color,
+										   self._moz_font, 
+										   self._moz_size, 
+										   self._css)] 
 			if self._USING_AJAX:
+				html.append("""<script type="text/javascript"><!--""")
 				html.append("""
 	            
 	            var xmlHttp
@@ -696,6 +745,14 @@ class PlanetView(gobject.GObject):
 			
 			html.append("--> </script>")
 			html.append("""</head><body><span id="errorMsg"></span><br>""")
+		else:
+			html = ["""<html><head>
+			    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
+<style type="text/css">
+%s
+</style>
+			    <title>title</title>""" % self._css] 
+			html.append("""</head><body>""")
 			
 		return "\n".join(html)
 		
@@ -809,17 +866,105 @@ class PlanetView(gobject.GObject):
 		#logging.debug("="*80)
 		#logging.debug(html)
 		#logging.debug("="*80)
-		if self._moz_realized or utils.RUNNING_SUGAR:
-			if self._USING_AJAX:
-				self._moz.open_stream("http://localhost:"+str(PlanetView.PORT),"text/html")
+		if self._renderer == EntryFormatter.MOZILLA:
+			if self._moz_realized or utils.RUNNING_SUGAR:
+				if self._USING_AJAX:
+					self._moz.open_stream("http://localhost:"+str(PlanetView.PORT),"text/html")
+				else:
+					self._moz.open_stream("file:///","text/html")
+				while len(html)>60000:
+					part = html[0:60000]
+					html = html[60000:]
+					self._moz.append_data(part, long(len(part)))
+				self._moz.append_data(html, long(len(html)))
+				self._moz.close_stream()
+		elif self._renderer == EntryFormatter.GTKHTML:
+			self._document_lock.acquire()
+			imgs = IMG_REGEX.findall(html)
+			uncached=0
+			for url in imgs:
+				if not self._image_cache.is_cached(url):
+					uncached+=1
+					
+			if uncached > 0:
+				self._document.clear()
+				self._document.open_stream("text/html")
+				d = { 	"background_color": self._background_color,
+						"loading": _("Loading images...")}
+				self._document.write_stream("""<html><style type="text/css">
+		        body { background-color: %(background_color)s; }</style><body><i>%(loading)s</i></body></html>""" % d) 
+				self._document.close_stream()
+				self._document_lock.release()
+				
+				self._dl_count = 0
+				self._dl_total = uncached
+				
+				for url in imgs:
+					if not self._image_cache.is_cached(url):
+						self._image_pool.queueTask(self._gtkhtml_do_download_image, (url, self._current_feed_id, self._first_entry), self._gtkhtml_image_dl_cb)
+				self._image_pool.queueTask(self._gtkhtml_download_done, (self._current_feed_id, self._first_entry, html))
 			else:
-				self._moz.open_stream("file:///","text/html")
-			while len(html)>60000:
-				part = html[0:60000]
-				html = html[60000:]
-				self._moz.append_data(part, long(len(part)))
-			self._moz.append_data(html, long(len(html)))
-			self._moz.close_stream()
+				self._document.clear()
+				self._document.open_stream("text/html")
+				self._document.write_stream(html)
+				self._document.close_stream()
+				self._document_lock.release()
+				
+	def _gtkhtml_reset_image_dl(self):
+		assert self._renderer == EntryFormatter.GTKHTML
+		self._image_pool.joinAll(False, False)
+		self._dl_count = 0
+		self._dl_total = 0
+				
+	def _gtkhtml_do_download_image(self, args):
+		url, feed_id, first_entry = args
+		self._image_cache.get_image(url)
+		return (feed_id, first_entry)
+		
+	def _gtkhtml_image_dl_cb(self, args):
+		feed_id, first_entry = args
+		if feed_id == self._current_feed_id and first_entry == self._first_entry:
+			self._dl_count += 1
+			
+	def _gtkhtml_download_done(self, args):
+		feed_id, first_entry, html = args
+		
+		count = 0
+		last_count = self._dl_count
+		while feed_id == self._current_feed_id and first_entry == self._first_entry and count < (10 * 2):
+			if last_count != self._dl_count:
+				#if downloads are still coming in, reset counter
+				last_count = self._dl_count
+				count = 0
+			if self._dl_count >= self._dl_total:
+				gobject.idle_add(self._gtkhtml_images_loaded, feed_id, first_entry, html)
+				return
+			count += 1
+			time.sleep(0.5)
+		gobject.idle_add(self._gtkhtml_images_loaded, feed_id, first_entry, html)
+
+		
+	def _gtkhtml_images_loaded(self, feed_id, first_entry, html):
+		#if we're changing, nevermind.
+		#also make sure entry is the same and that we shouldn't be blanks
+		if feed_id == self._current_feed_id and first_entry == self._first_entry:
+			va = self._scrolled_window.get_vadjustment()
+			ha = self._scrolled_window.get_hadjustment()
+			self._document_lock.acquire()
+			self._document.clear()
+			self._document.open_stream("text/html")
+			self._document.write_stream(html)
+			self._document.close_stream()
+			self._document_lock.release()
+		return False
+		
+	def _gtkhtml_request_url(self, document, url, stream):
+		try:
+			image = self._image_cache.get_image(url)
+			stream.write(image)
+			stream.close()
+		except Exception, ex:
+			stream.close()
 			
 	def _do_delayed_set_viewed(self, feed_id, first_entry, last_entry, show_change=False):
 		if (feed_id, first_entry, last_entry) != \
@@ -936,18 +1081,24 @@ class PlanetView(gobject.GObject):
 		
 	def _moz_link_clicked(self, mozembed, link):
 		link = link.strip()
+		self._link_clicked(link)
+		return True #don't load url please
+		
+	def _link_clicked(self, link):
 		if link == "planet:up":
 			self._first_entry -= ENTRIES_PER_PAGE
+			if self._renderer == EntryFormatter.GTKHTML:
+				self._gtkhtml_reset_image_dl()
 			self._render_entries(mark_read=True)
 		elif link == "planet:down":
 			self._first_entry += ENTRIES_PER_PAGE
+			if self._renderer == EntryFormatter.GTKHTML:
+				self._gtkhtml_reset_image_dl()
 			self._render_entries(mark_read=True)
 		elif link.startswith("rightclick"):
 			self._do_context_menu(int(link.split(':')[1]))
 		else:
 			self.emit('link-activated', link)
-			
-		return True #don't load url please
 		
 	def set_hide_viewed(self, state):
 		if state == self._hide_viewed:
@@ -975,6 +1126,15 @@ class PlanetView(gobject.GObject):
 	def _moz_link_message(self, data):
 		if not utils.RUNNING_HILDON:
 			self._main_window.display_status_message(self._moz.get_link_message())
+			
+	def _gtkhtml_link_clicked(self, document, link):
+		link = link.strip()
+		self._link_clicked(link)
+	
+	def _gtkhtml_on_url(self, view, url):
+		if url == None:
+			url = ""
+		self._main_window.display_status_message(url)
 	
 	def _gconf_reset_moz_font(self, client, *args, **kwargs):
 		self._reset_moz_font()
